# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheActivityObsViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avalanche_activity_obs_id': 'int',
        'aspect': 'int',
        'heigth_start_zone': 'int',
        'dt_avalanche_time': 'datetime',
        'destructive_size_tid': 'int',
        'destructive_size_name': 'str',
        'estimated_num_tid': 'int',
        'estimated_num_name': 'str',
        'avalanche_tid': 'int',
        'avalanche_name': 'str',
        'avalanche_trigger_tid': 'int',
        'avalanche_trigger_name': 'str',
        'terrain_start_zone_tid': 'int',
        'terrain_start_zone_name': 'str',
        'snow_line': 'int',
        'snow_line_name': 'str',
        'comment': 'str',
        'dt_off_avalanche_time': 'datetime'
    }

    attribute_map = {
        'avalanche_activity_obs_id': 'AvalancheActivityObsID',
        'aspect': 'Aspect',
        'heigth_start_zone': 'HeigthStartZone',
        'dt_avalanche_time': 'DtAvalancheTime',
        'destructive_size_tid': 'DestructiveSizeTID',
        'destructive_size_name': 'DestructiveSizeName',
        'estimated_num_tid': 'EstimatedNumTID',
        'estimated_num_name': 'EstimatedNumName',
        'avalanche_tid': 'AvalancheTID',
        'avalanche_name': 'AvalancheName',
        'avalanche_trigger_tid': 'AvalancheTriggerTID',
        'avalanche_trigger_name': 'AvalancheTriggerName',
        'terrain_start_zone_tid': 'TerrainStartZoneTID',
        'terrain_start_zone_name': 'TerrainStartZoneName',
        'snow_line': 'SnowLine',
        'snow_line_name': 'SnowLineName',
        'comment': 'Comment',
        'dt_off_avalanche_time': 'DtOffAvalancheTime'
    }

    def __init__(self, avalanche_activity_obs_id=None, aspect=None, heigth_start_zone=None, dt_avalanche_time=None, destructive_size_tid=None, destructive_size_name=None, estimated_num_tid=None, estimated_num_name=None, avalanche_tid=None, avalanche_name=None, avalanche_trigger_tid=None, avalanche_trigger_name=None, terrain_start_zone_tid=None, terrain_start_zone_name=None, snow_line=None, snow_line_name=None, comment=None, dt_off_avalanche_time=None):  # noqa: E501
        """AvalancheActivityObsViewModel - a model defined in Swagger"""  # noqa: E501
        self._avalanche_activity_obs_id = None
        self._aspect = None
        self._heigth_start_zone = None
        self._dt_avalanche_time = None
        self._destructive_size_tid = None
        self._destructive_size_name = None
        self._estimated_num_tid = None
        self._estimated_num_name = None
        self._avalanche_tid = None
        self._avalanche_name = None
        self._avalanche_trigger_tid = None
        self._avalanche_trigger_name = None
        self._terrain_start_zone_tid = None
        self._terrain_start_zone_name = None
        self._snow_line = None
        self._snow_line_name = None
        self._comment = None
        self._dt_off_avalanche_time = None
        self.discriminator = None
        if avalanche_activity_obs_id is not None:
            self.avalanche_activity_obs_id = avalanche_activity_obs_id
        if aspect is not None:
            self.aspect = aspect
        if heigth_start_zone is not None:
            self.heigth_start_zone = heigth_start_zone
        if dt_avalanche_time is not None:
            self.dt_avalanche_time = dt_avalanche_time
        if destructive_size_tid is not None:
            self.destructive_size_tid = destructive_size_tid
        if destructive_size_name is not None:
            self.destructive_size_name = destructive_size_name
        if estimated_num_tid is not None:
            self.estimated_num_tid = estimated_num_tid
        if estimated_num_name is not None:
            self.estimated_num_name = estimated_num_name
        if avalanche_tid is not None:
            self.avalanche_tid = avalanche_tid
        if avalanche_name is not None:
            self.avalanche_name = avalanche_name
        if avalanche_trigger_tid is not None:
            self.avalanche_trigger_tid = avalanche_trigger_tid
        if avalanche_trigger_name is not None:
            self.avalanche_trigger_name = avalanche_trigger_name
        if terrain_start_zone_tid is not None:
            self.terrain_start_zone_tid = terrain_start_zone_tid
        if terrain_start_zone_name is not None:
            self.terrain_start_zone_name = terrain_start_zone_name
        if snow_line is not None:
            self.snow_line = snow_line
        if snow_line_name is not None:
            self.snow_line_name = snow_line_name
        if comment is not None:
            self.comment = comment
        if dt_off_avalanche_time is not None:
            self.dt_off_avalanche_time = dt_off_avalanche_time

    @property
    def avalanche_activity_obs_id(self):
        """Gets the avalanche_activity_obs_id of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The avalanche_activity_obs_id of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_activity_obs_id

    @avalanche_activity_obs_id.setter
    def avalanche_activity_obs_id(self, avalanche_activity_obs_id):
        """Sets the avalanche_activity_obs_id of this AvalancheActivityObsViewModel.


        :param avalanche_activity_obs_id: The avalanche_activity_obs_id of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_activity_obs_id = avalanche_activity_obs_id

    @property
    def aspect(self):
        """Gets the aspect of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The aspect of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aspect

    @aspect.setter
    def aspect(self, aspect):
        """Sets the aspect of this AvalancheActivityObsViewModel.


        :param aspect: The aspect of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._aspect = aspect

    @property
    def heigth_start_zone(self):
        """Gets the heigth_start_zone of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The heigth_start_zone of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._heigth_start_zone

    @heigth_start_zone.setter
    def heigth_start_zone(self, heigth_start_zone):
        """Sets the heigth_start_zone of this AvalancheActivityObsViewModel.


        :param heigth_start_zone: The heigth_start_zone of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._heigth_start_zone = heigth_start_zone

    @property
    def dt_avalanche_time(self):
        """Gets the dt_avalanche_time of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The dt_avalanche_time of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_avalanche_time

    @dt_avalanche_time.setter
    def dt_avalanche_time(self, dt_avalanche_time):
        """Sets the dt_avalanche_time of this AvalancheActivityObsViewModel.


        :param dt_avalanche_time: The dt_avalanche_time of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_avalanche_time = dt_avalanche_time

    @property
    def destructive_size_tid(self):
        """Gets the destructive_size_tid of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The destructive_size_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._destructive_size_tid

    @destructive_size_tid.setter
    def destructive_size_tid(self, destructive_size_tid):
        """Sets the destructive_size_tid of this AvalancheActivityObsViewModel.


        :param destructive_size_tid: The destructive_size_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._destructive_size_tid = destructive_size_tid

    @property
    def destructive_size_name(self):
        """Gets the destructive_size_name of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The destructive_size_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._destructive_size_name

    @destructive_size_name.setter
    def destructive_size_name(self, destructive_size_name):
        """Sets the destructive_size_name of this AvalancheActivityObsViewModel.


        :param destructive_size_name: The destructive_size_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: str
        """

        self._destructive_size_name = destructive_size_name

    @property
    def estimated_num_tid(self):
        """Gets the estimated_num_tid of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The estimated_num_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._estimated_num_tid

    @estimated_num_tid.setter
    def estimated_num_tid(self, estimated_num_tid):
        """Sets the estimated_num_tid of this AvalancheActivityObsViewModel.


        :param estimated_num_tid: The estimated_num_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._estimated_num_tid = estimated_num_tid

    @property
    def estimated_num_name(self):
        """Gets the estimated_num_name of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The estimated_num_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._estimated_num_name

    @estimated_num_name.setter
    def estimated_num_name(self, estimated_num_name):
        """Sets the estimated_num_name of this AvalancheActivityObsViewModel.


        :param estimated_num_name: The estimated_num_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: str
        """

        self._estimated_num_name = estimated_num_name

    @property
    def avalanche_tid(self):
        """Gets the avalanche_tid of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The avalanche_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_tid

    @avalanche_tid.setter
    def avalanche_tid(self, avalanche_tid):
        """Sets the avalanche_tid of this AvalancheActivityObsViewModel.


        :param avalanche_tid: The avalanche_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_tid = avalanche_tid

    @property
    def avalanche_name(self):
        """Gets the avalanche_name of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The avalanche_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_name

    @avalanche_name.setter
    def avalanche_name(self, avalanche_name):
        """Sets the avalanche_name of this AvalancheActivityObsViewModel.


        :param avalanche_name: The avalanche_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_name = avalanche_name

    @property
    def avalanche_trigger_tid(self):
        """Gets the avalanche_trigger_tid of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The avalanche_trigger_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_trigger_tid

    @avalanche_trigger_tid.setter
    def avalanche_trigger_tid(self, avalanche_trigger_tid):
        """Sets the avalanche_trigger_tid of this AvalancheActivityObsViewModel.


        :param avalanche_trigger_tid: The avalanche_trigger_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_trigger_tid = avalanche_trigger_tid

    @property
    def avalanche_trigger_name(self):
        """Gets the avalanche_trigger_name of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The avalanche_trigger_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_trigger_name

    @avalanche_trigger_name.setter
    def avalanche_trigger_name(self, avalanche_trigger_name):
        """Sets the avalanche_trigger_name of this AvalancheActivityObsViewModel.


        :param avalanche_trigger_name: The avalanche_trigger_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_trigger_name = avalanche_trigger_name

    @property
    def terrain_start_zone_tid(self):
        """Gets the terrain_start_zone_tid of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The terrain_start_zone_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._terrain_start_zone_tid

    @terrain_start_zone_tid.setter
    def terrain_start_zone_tid(self, terrain_start_zone_tid):
        """Sets the terrain_start_zone_tid of this AvalancheActivityObsViewModel.


        :param terrain_start_zone_tid: The terrain_start_zone_tid of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._terrain_start_zone_tid = terrain_start_zone_tid

    @property
    def terrain_start_zone_name(self):
        """Gets the terrain_start_zone_name of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The terrain_start_zone_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._terrain_start_zone_name

    @terrain_start_zone_name.setter
    def terrain_start_zone_name(self, terrain_start_zone_name):
        """Sets the terrain_start_zone_name of this AvalancheActivityObsViewModel.


        :param terrain_start_zone_name: The terrain_start_zone_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: str
        """

        self._terrain_start_zone_name = terrain_start_zone_name

    @property
    def snow_line(self):
        """Gets the snow_line of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The snow_line of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._snow_line

    @snow_line.setter
    def snow_line(self, snow_line):
        """Sets the snow_line of this AvalancheActivityObsViewModel.


        :param snow_line: The snow_line of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: int
        """

        self._snow_line = snow_line

    @property
    def snow_line_name(self):
        """Gets the snow_line_name of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The snow_line_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._snow_line_name

    @snow_line_name.setter
    def snow_line_name(self, snow_line_name):
        """Sets the snow_line_name of this AvalancheActivityObsViewModel.


        :param snow_line_name: The snow_line_name of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: str
        """

        self._snow_line_name = snow_line_name

    @property
    def comment(self):
        """Gets the comment of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The comment of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheActivityObsViewModel.


        :param comment: The comment of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def dt_off_avalanche_time(self):
        """Gets the dt_off_avalanche_time of this AvalancheActivityObsViewModel.  # noqa: E501


        :return: The dt_off_avalanche_time of this AvalancheActivityObsViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_off_avalanche_time

    @dt_off_avalanche_time.setter
    def dt_off_avalanche_time(self, dt_off_avalanche_time):
        """Sets the dt_off_avalanche_time of this AvalancheActivityObsViewModel.


        :param dt_off_avalanche_time: The dt_off_avalanche_time of this AvalancheActivityObsViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_off_avalanche_time = dt_off_avalanche_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheActivityObsViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheActivityObsViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from varsom_regobs_client.api_client import ApiClient


class SearchApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def search_at_a_glance(self, body, **kwargs):  # noqa: E501
        """Returns simplified registrations.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_at_a_glance(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchCriteriaRequestDto body: Search criteria (required)
        :return: list[AtAGlanceViewModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_at_a_glance_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.search_at_a_glance_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def search_at_a_glance_with_http_info(self, body, **kwargs):  # noqa: E501
        """Returns simplified registrations.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_at_a_glance_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchCriteriaRequestDto body: Search criteria (required)
        :return: list[AtAGlanceViewModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_at_a_glance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `search_at_a_glance`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Search/AtAGlance', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AtAGlanceViewModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_count(self, body, **kwargs):  # noqa: E501
        """Returns search result count  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_count(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchCriteriaRequestDto body: Search criteria (required)
        :return: SearchCountResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_count_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.search_count_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def search_count_with_http_info(self, body, **kwargs):  # noqa: E501
        """Returns search result count  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_count_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchCriteriaRequestDto body: Search criteria (required)
        :return: SearchCountResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_count" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `search_count`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Search/Count', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchCountResponseDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_search(self, body, **kwargs):  # noqa: E501
        """Registration search  # noqa: E501

        Example critera for returning the 10 newest registrations:  <code>      { \"NumberOfRecords\": 10 }  </code>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_search(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchCriteriaRequestDto body: Search criteria. (required)
        :return: list[RegistrationViewModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_search_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.search_search_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def search_search_with_http_info(self, body, **kwargs):  # noqa: E501
        """Registration search  # noqa: E501

        Example critera for returning the 10 newest registrations:  <code>      { \"NumberOfRecords\": 10 }  </code>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_search_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchCriteriaRequestDto body: Search criteria. (required)
        :return: list[RegistrationViewModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_search" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `search_search`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RegistrationViewModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_search_criteria(self, body, **kwargs):  # noqa: E501
        """Returns search criteria for the specified hazard type and language.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_search_criteria(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchSideBarRequestDto body: (required)
        :return: SearchSideBarDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_search_criteria_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.search_search_criteria_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def search_search_criteria_with_http_info(self, body, **kwargs):  # noqa: E501
        """Returns search criteria for the specified hazard type and language.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_search_criteria_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchSideBarRequestDto body: (required)
        :return: SearchSideBarDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_search_criteria" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `search_search_criteria`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Search/SearchCriteria', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchSideBarDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ObsLocationsResponseDtoV2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'int',
        'distance': 'float',
        'lat_lng_object': 'LatLngObject',
        'observer_nick_name': 'str',
        'observer_group_name': 'str',
        'observer_group_id': 'int',
        'geo_hazard_id': 'int'
    }

    attribute_map = {
        'name': 'Name',
        'id': 'Id',
        'distance': 'Distance',
        'lat_lng_object': 'LatLngObject',
        'observer_nick_name': 'ObserverNickName',
        'observer_group_name': 'ObserverGroupName',
        'observer_group_id': 'ObserverGroupId',
        'geo_hazard_id': 'GeoHazardId'
    }

    def __init__(self, name=None, id=None, distance=None, lat_lng_object=None, observer_nick_name=None, observer_group_name=None, observer_group_id=None, geo_hazard_id=None):  # noqa: E501
        """ObsLocationsResponseDtoV2 - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._id = None
        self._distance = None
        self._lat_lng_object = None
        self._observer_nick_name = None
        self._observer_group_name = None
        self._observer_group_id = None
        self._geo_hazard_id = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if distance is not None:
            self.distance = distance
        if lat_lng_object is not None:
            self.lat_lng_object = lat_lng_object
        if observer_nick_name is not None:
            self.observer_nick_name = observer_nick_name
        if observer_group_name is not None:
            self.observer_group_name = observer_group_name
        if observer_group_id is not None:
            self.observer_group_id = observer_group_id
        if geo_hazard_id is not None:
            self.geo_hazard_id = geo_hazard_id

    @property
    def name(self):
        """Gets the name of this ObsLocationsResponseDtoV2.  # noqa: E501


        :return: The name of this ObsLocationsResponseDtoV2.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ObsLocationsResponseDtoV2.


        :param name: The name of this ObsLocationsResponseDtoV2.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this ObsLocationsResponseDtoV2.  # noqa: E501


        :return: The id of this ObsLocationsResponseDtoV2.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ObsLocationsResponseDtoV2.


        :param id: The id of this ObsLocationsResponseDtoV2.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def distance(self):
        """Gets the distance of this ObsLocationsResponseDtoV2.  # noqa: E501


        :return: The distance of this ObsLocationsResponseDtoV2.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this ObsLocationsResponseDtoV2.


        :param distance: The distance of this ObsLocationsResponseDtoV2.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def lat_lng_object(self):
        """Gets the lat_lng_object of this ObsLocationsResponseDtoV2.  # noqa: E501


        :return: The lat_lng_object of this ObsLocationsResponseDtoV2.  # noqa: E501
        :rtype: LatLngObject
        """
        return self._lat_lng_object

    @lat_lng_object.setter
    def lat_lng_object(self, lat_lng_object):
        """Sets the lat_lng_object of this ObsLocationsResponseDtoV2.


        :param lat_lng_object: The lat_lng_object of this ObsLocationsResponseDtoV2.  # noqa: E501
        :type: LatLngObject
        """

        self._lat_lng_object = lat_lng_object

    @property
    def observer_nick_name(self):
        """Gets the observer_nick_name of this ObsLocationsResponseDtoV2.  # noqa: E501


        :return: The observer_nick_name of this ObsLocationsResponseDtoV2.  # noqa: E501
        :rtype: str
        """
        return self._observer_nick_name

    @observer_nick_name.setter
    def observer_nick_name(self, observer_nick_name):
        """Sets the observer_nick_name of this ObsLocationsResponseDtoV2.


        :param observer_nick_name: The observer_nick_name of this ObsLocationsResponseDtoV2.  # noqa: E501
        :type: str
        """

        self._observer_nick_name = observer_nick_name

    @property
    def observer_group_name(self):
        """Gets the observer_group_name of this ObsLocationsResponseDtoV2.  # noqa: E501


        :return: The observer_group_name of this ObsLocationsResponseDtoV2.  # noqa: E501
        :rtype: str
        """
        return self._observer_group_name

    @observer_group_name.setter
    def observer_group_name(self, observer_group_name):
        """Sets the observer_group_name of this ObsLocationsResponseDtoV2.


        :param observer_group_name: The observer_group_name of this ObsLocationsResponseDtoV2.  # noqa: E501
        :type: str
        """

        self._observer_group_name = observer_group_name

    @property
    def observer_group_id(self):
        """Gets the observer_group_id of this ObsLocationsResponseDtoV2.  # noqa: E501


        :return: The observer_group_id of this ObsLocationsResponseDtoV2.  # noqa: E501
        :rtype: int
        """
        return self._observer_group_id

    @observer_group_id.setter
    def observer_group_id(self, observer_group_id):
        """Sets the observer_group_id of this ObsLocationsResponseDtoV2.


        :param observer_group_id: The observer_group_id of this ObsLocationsResponseDtoV2.  # noqa: E501
        :type: int
        """

        self._observer_group_id = observer_group_id

    @property
    def geo_hazard_id(self):
        """Gets the geo_hazard_id of this ObsLocationsResponseDtoV2.  # noqa: E501


        :return: The geo_hazard_id of this ObsLocationsResponseDtoV2.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_id

    @geo_hazard_id.setter
    def geo_hazard_id(self, geo_hazard_id):
        """Sets the geo_hazard_id of this ObsLocationsResponseDtoV2.


        :param geo_hazard_id: The geo_hazard_id of this ObsLocationsResponseDtoV2.  # noqa: E501
        :type: int
        """

        self._geo_hazard_id = geo_hazard_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ObsLocationsResponseDtoV2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObsLocationsResponseDtoV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class LandSlideObsDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_lat': 'float',
        'start_long': 'float',
        'stop_lat': 'float',
        'stop_long': 'float',
        'dt_land_slide_time': 'datetime',
        'dt_land_slide_time_end': 'datetime',
        'utm_north_start': 'int',
        'utm_east_start': 'int',
        'utm_zone_start': 'int',
        'utm_north_stop': 'int',
        'utm_east_stop': 'int',
        'utm_zone_stop': 'int',
        'land_slide_tid': 'int',
        'land_slide_trigger_tid': 'int',
        'land_slide_size_tid': 'int',
        'usage_flag_tid': 'int',
        'geo_hazard_tid': 'int',
        'activity_influenced_tid': 'int',
        'forecast_accurate_tid': 'int',
        'damage_extent_tid': 'int',
        'comment': 'str',
        'urls': 'list[UrlViewModel]'
    }

    attribute_map = {
        'start_lat': 'StartLat',
        'start_long': 'StartLong',
        'stop_lat': 'StopLat',
        'stop_long': 'StopLong',
        'dt_land_slide_time': 'DtLandSlideTime',
        'dt_land_slide_time_end': 'DtLandSlideTimeEnd',
        'utm_north_start': 'UTMNorthStart',
        'utm_east_start': 'UTMEastStart',
        'utm_zone_start': 'UTMZoneStart',
        'utm_north_stop': 'UTMNorthStop',
        'utm_east_stop': 'UTMEastStop',
        'utm_zone_stop': 'UTMZoneStop',
        'land_slide_tid': 'LandSlideTID',
        'land_slide_trigger_tid': 'LandSlideTriggerTID',
        'land_slide_size_tid': 'LandSlideSizeTID',
        'usage_flag_tid': 'UsageFlagTID',
        'geo_hazard_tid': 'GeoHazardTID',
        'activity_influenced_tid': 'ActivityInfluencedTID',
        'forecast_accurate_tid': 'ForecastAccurateTID',
        'damage_extent_tid': 'DamageExtentTID',
        'comment': 'Comment',
        'urls': 'Urls'
    }

    def __init__(self, start_lat=None, start_long=None, stop_lat=None, stop_long=None, dt_land_slide_time=None, dt_land_slide_time_end=None, utm_north_start=None, utm_east_start=None, utm_zone_start=None, utm_north_stop=None, utm_east_stop=None, utm_zone_stop=None, land_slide_tid=None, land_slide_trigger_tid=None, land_slide_size_tid=None, usage_flag_tid=None, geo_hazard_tid=None, activity_influenced_tid=None, forecast_accurate_tid=None, damage_extent_tid=None, comment=None, urls=None):  # noqa: E501
        """LandSlideObsDto - a model defined in Swagger"""  # noqa: E501
        self._start_lat = None
        self._start_long = None
        self._stop_lat = None
        self._stop_long = None
        self._dt_land_slide_time = None
        self._dt_land_slide_time_end = None
        self._utm_north_start = None
        self._utm_east_start = None
        self._utm_zone_start = None
        self._utm_north_stop = None
        self._utm_east_stop = None
        self._utm_zone_stop = None
        self._land_slide_tid = None
        self._land_slide_trigger_tid = None
        self._land_slide_size_tid = None
        self._usage_flag_tid = None
        self._geo_hazard_tid = None
        self._activity_influenced_tid = None
        self._forecast_accurate_tid = None
        self._damage_extent_tid = None
        self._comment = None
        self._urls = None
        self.discriminator = None
        if start_lat is not None:
            self.start_lat = start_lat
        if start_long is not None:
            self.start_long = start_long
        if stop_lat is not None:
            self.stop_lat = stop_lat
        if stop_long is not None:
            self.stop_long = stop_long
        self.dt_land_slide_time = dt_land_slide_time
        if dt_land_slide_time_end is not None:
            self.dt_land_slide_time_end = dt_land_slide_time_end
        if utm_north_start is not None:
            self.utm_north_start = utm_north_start
        if utm_east_start is not None:
            self.utm_east_start = utm_east_start
        if utm_zone_start is not None:
            self.utm_zone_start = utm_zone_start
        if utm_north_stop is not None:
            self.utm_north_stop = utm_north_stop
        if utm_east_stop is not None:
            self.utm_east_stop = utm_east_stop
        if utm_zone_stop is not None:
            self.utm_zone_stop = utm_zone_stop
        if land_slide_tid is not None:
            self.land_slide_tid = land_slide_tid
        if land_slide_trigger_tid is not None:
            self.land_slide_trigger_tid = land_slide_trigger_tid
        if land_slide_size_tid is not None:
            self.land_slide_size_tid = land_slide_size_tid
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if activity_influenced_tid is not None:
            self.activity_influenced_tid = activity_influenced_tid
        if forecast_accurate_tid is not None:
            self.forecast_accurate_tid = forecast_accurate_tid
        if damage_extent_tid is not None:
            self.damage_extent_tid = damage_extent_tid
        if comment is not None:
            self.comment = comment
        if urls is not None:
            self.urls = urls

    @property
    def start_lat(self):
        """Gets the start_lat of this LandSlideObsDto.  # noqa: E501

        Latitude start posisjon  # noqa: E501

        :return: The start_lat of this LandSlideObsDto.  # noqa: E501
        :rtype: float
        """
        return self._start_lat

    @start_lat.setter
    def start_lat(self, start_lat):
        """Sets the start_lat of this LandSlideObsDto.

        Latitude start posisjon  # noqa: E501

        :param start_lat: The start_lat of this LandSlideObsDto.  # noqa: E501
        :type: float
        """

        self._start_lat = start_lat

    @property
    def start_long(self):
        """Gets the start_long of this LandSlideObsDto.  # noqa: E501

        Long start posisjon  # noqa: E501

        :return: The start_long of this LandSlideObsDto.  # noqa: E501
        :rtype: float
        """
        return self._start_long

    @start_long.setter
    def start_long(self, start_long):
        """Sets the start_long of this LandSlideObsDto.

        Long start posisjon  # noqa: E501

        :param start_long: The start_long of this LandSlideObsDto.  # noqa: E501
        :type: float
        """

        self._start_long = start_long

    @property
    def stop_lat(self):
        """Gets the stop_lat of this LandSlideObsDto.  # noqa: E501

        Latitude stopp posisjon  # noqa: E501

        :return: The stop_lat of this LandSlideObsDto.  # noqa: E501
        :rtype: float
        """
        return self._stop_lat

    @stop_lat.setter
    def stop_lat(self, stop_lat):
        """Sets the stop_lat of this LandSlideObsDto.

        Latitude stopp posisjon  # noqa: E501

        :param stop_lat: The stop_lat of this LandSlideObsDto.  # noqa: E501
        :type: float
        """

        self._stop_lat = stop_lat

    @property
    def stop_long(self):
        """Gets the stop_long of this LandSlideObsDto.  # noqa: E501

        Long stopp posisjon  # noqa: E501

        :return: The stop_long of this LandSlideObsDto.  # noqa: E501
        :rtype: float
        """
        return self._stop_long

    @stop_long.setter
    def stop_long(self, stop_long):
        """Sets the stop_long of this LandSlideObsDto.

        Long stopp posisjon  # noqa: E501

        :param stop_long: The stop_long of this LandSlideObsDto.  # noqa: E501
        :type: float
        """

        self._stop_long = stop_long

    @property
    def dt_land_slide_time(self):
        """Gets the dt_land_slide_time of this LandSlideObsDto.  # noqa: E501

        Når gikk skredet? Dette er ikke det samme tidspunktet da skredet ble observert.  # noqa: E501

        :return: The dt_land_slide_time of this LandSlideObsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_land_slide_time

    @dt_land_slide_time.setter
    def dt_land_slide_time(self, dt_land_slide_time):
        """Sets the dt_land_slide_time of this LandSlideObsDto.

        Når gikk skredet? Dette er ikke det samme tidspunktet da skredet ble observert.  # noqa: E501

        :param dt_land_slide_time: The dt_land_slide_time of this LandSlideObsDto.  # noqa: E501
        :type: datetime
        """
        if dt_land_slide_time is None:
            raise ValueError("Invalid value for `dt_land_slide_time`, must not be `None`")  # noqa: E501

        self._dt_land_slide_time = dt_land_slide_time

    @property
    def dt_land_slide_time_end(self):
        """Gets the dt_land_slide_time_end of this LandSlideObsDto.  # noqa: E501

        Når stoppet skredet?  # noqa: E501

        :return: The dt_land_slide_time_end of this LandSlideObsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_land_slide_time_end

    @dt_land_slide_time_end.setter
    def dt_land_slide_time_end(self, dt_land_slide_time_end):
        """Sets the dt_land_slide_time_end of this LandSlideObsDto.

        Når stoppet skredet?  # noqa: E501

        :param dt_land_slide_time_end: The dt_land_slide_time_end of this LandSlideObsDto.  # noqa: E501
        :type: datetime
        """

        self._dt_land_slide_time_end = dt_land_slide_time_end

    @property
    def utm_north_start(self):
        """Gets the utm_north_start of this LandSlideObsDto.  # noqa: E501

        Hvor startet skredet? Nordlig UTM sone uten desimaler.  # noqa: E501

        :return: The utm_north_start of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_north_start

    @utm_north_start.setter
    def utm_north_start(self, utm_north_start):
        """Sets the utm_north_start of this LandSlideObsDto.

        Hvor startet skredet? Nordlig UTM sone uten desimaler.  # noqa: E501

        :param utm_north_start: The utm_north_start of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._utm_north_start = utm_north_start

    @property
    def utm_east_start(self):
        """Gets the utm_east_start of this LandSlideObsDto.  # noqa: E501

        Hvor startet skredet? Østlig UTM sone uten desimaler.  # noqa: E501

        :return: The utm_east_start of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_east_start

    @utm_east_start.setter
    def utm_east_start(self, utm_east_start):
        """Sets the utm_east_start of this LandSlideObsDto.

        Hvor startet skredet? Østlig UTM sone uten desimaler.  # noqa: E501

        :param utm_east_start: The utm_east_start of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._utm_east_start = utm_east_start

    @property
    def utm_zone_start(self):
        """Gets the utm_zone_start of this LandSlideObsDto.  # noqa: E501

        Hvor startet skredet? UTM sone. Merk at kartene i norge ligger mellom UTM32 og 34.  # noqa: E501

        :return: The utm_zone_start of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_zone_start

    @utm_zone_start.setter
    def utm_zone_start(self, utm_zone_start):
        """Sets the utm_zone_start of this LandSlideObsDto.

        Hvor startet skredet? UTM sone. Merk at kartene i norge ligger mellom UTM32 og 34.  # noqa: E501

        :param utm_zone_start: The utm_zone_start of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._utm_zone_start = utm_zone_start

    @property
    def utm_north_stop(self):
        """Gets the utm_north_stop of this LandSlideObsDto.  # noqa: E501

        Hvor stoppet skredet? Nordlig UTM sone uten desimaler.  # noqa: E501

        :return: The utm_north_stop of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_north_stop

    @utm_north_stop.setter
    def utm_north_stop(self, utm_north_stop):
        """Sets the utm_north_stop of this LandSlideObsDto.

        Hvor stoppet skredet? Nordlig UTM sone uten desimaler.  # noqa: E501

        :param utm_north_stop: The utm_north_stop of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._utm_north_stop = utm_north_stop

    @property
    def utm_east_stop(self):
        """Gets the utm_east_stop of this LandSlideObsDto.  # noqa: E501

        Hvor stoppet skredet? Østlig UTM sone uten desimaler.  # noqa: E501

        :return: The utm_east_stop of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_east_stop

    @utm_east_stop.setter
    def utm_east_stop(self, utm_east_stop):
        """Sets the utm_east_stop of this LandSlideObsDto.

        Hvor stoppet skredet? Østlig UTM sone uten desimaler.  # noqa: E501

        :param utm_east_stop: The utm_east_stop of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._utm_east_stop = utm_east_stop

    @property
    def utm_zone_stop(self):
        """Gets the utm_zone_stop of this LandSlideObsDto.  # noqa: E501

        Hvor stoppet skredet? UTM sone. Merk at kartene i norge ligger mellom UTM32 og 34.  # noqa: E501

        :return: The utm_zone_stop of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_zone_stop

    @utm_zone_stop.setter
    def utm_zone_stop(self, utm_zone_stop):
        """Sets the utm_zone_stop of this LandSlideObsDto.

        Hvor stoppet skredet? UTM sone. Merk at kartene i norge ligger mellom UTM32 og 34.  # noqa: E501

        :param utm_zone_stop: The utm_zone_stop of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._utm_zone_stop = utm_zone_stop

    @property
    def land_slide_tid(self):
        """Gets the land_slide_tid of this LandSlideObsDto.  # noqa: E501

        Hva slags type skred er det snakk om? Valg gitt i LandSlideKD. The LandSlideKD unique identifier  # noqa: E501

        :return: The land_slide_tid of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._land_slide_tid

    @land_slide_tid.setter
    def land_slide_tid(self, land_slide_tid):
        """Sets the land_slide_tid of this LandSlideObsDto.

        Hva slags type skred er det snakk om? Valg gitt i LandSlideKD. The LandSlideKD unique identifier  # noqa: E501

        :param land_slide_tid: The land_slide_tid of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._land_slide_tid = land_slide_tid

    @property
    def land_slide_trigger_tid(self):
        """Gets the land_slide_trigger_tid of this LandSlideObsDto.  # noqa: E501

        Hva utløste skredet? The LandSlideTriggerKD unique identifier  # noqa: E501

        :return: The land_slide_trigger_tid of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._land_slide_trigger_tid

    @land_slide_trigger_tid.setter
    def land_slide_trigger_tid(self, land_slide_trigger_tid):
        """Sets the land_slide_trigger_tid of this LandSlideObsDto.

        Hva utløste skredet? The LandSlideTriggerKD unique identifier  # noqa: E501

        :param land_slide_trigger_tid: The land_slide_trigger_tid of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._land_slide_trigger_tid = land_slide_trigger_tid

    @property
    def land_slide_size_tid(self):
        """Gets the land_slide_size_tid of this LandSlideObsDto.  # noqa: E501

        Hvor stort er skredet? The LandSlideSizeKD unique identifier  # noqa: E501

        :return: The land_slide_size_tid of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._land_slide_size_tid

    @land_slide_size_tid.setter
    def land_slide_size_tid(self, land_slide_size_tid):
        """Sets the land_slide_size_tid of this LandSlideObsDto.

        Hvor stort er skredet? The LandSlideSizeKD unique identifier  # noqa: E501

        :param land_slide_size_tid: The land_slide_size_tid of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._land_slide_size_tid = land_slide_size_tid

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this LandSlideObsDto.  # noqa: E501

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm. The UsageFlagKD unique identifier  # noqa: E501

        :return: The usage_flag_tid of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this LandSlideObsDto.

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm. The UsageFlagKD unique identifier  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this LandSlideObsDto.  # noqa: E501

        Spesifiser skredtype. vått jordskred?, jordskred eller steinskred? GeoHazardTID = 20, 30 og 40 er aktuelle. The GeoHazardKD unique identifier  # noqa: E501

        :return: The geo_hazard_tid of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this LandSlideObsDto.

        Spesifiser skredtype. vått jordskred?, jordskred eller steinskred? GeoHazardTID = 20, 30 og 40 er aktuelle. The GeoHazardKD unique identifier  # noqa: E501

        :param geo_hazard_tid: The geo_hazard_tid of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def activity_influenced_tid(self):
        """Gets the activity_influenced_tid of this LandSlideObsDto.  # noqa: E501

        Hva ble påvirket av hendelsen. Valgene er gitt i ActivityInfluencedKD. The ActivityInfluencedKD unique identifier  # noqa: E501

        :return: The activity_influenced_tid of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._activity_influenced_tid

    @activity_influenced_tid.setter
    def activity_influenced_tid(self, activity_influenced_tid):
        """Sets the activity_influenced_tid of this LandSlideObsDto.

        Hva ble påvirket av hendelsen. Valgene er gitt i ActivityInfluencedKD. The ActivityInfluencedKD unique identifier  # noqa: E501

        :param activity_influenced_tid: The activity_influenced_tid of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._activity_influenced_tid = activity_influenced_tid

    @property
    def forecast_accurate_tid(self):
        """Gets the forecast_accurate_tid of this LandSlideObsDto.  # noqa: E501

        Var det et varsel utstedt og stemte det? The ForecastAccurateKD unique identifier  # noqa: E501

        :return: The forecast_accurate_tid of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._forecast_accurate_tid

    @forecast_accurate_tid.setter
    def forecast_accurate_tid(self, forecast_accurate_tid):
        """Sets the forecast_accurate_tid of this LandSlideObsDto.

        Var det et varsel utstedt og stemte det? The ForecastAccurateKD unique identifier  # noqa: E501

        :param forecast_accurate_tid: The forecast_accurate_tid of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._forecast_accurate_tid = forecast_accurate_tid

    @property
    def damage_extent_tid(self):
        """Gets the damage_extent_tid of this LandSlideObsDto.  # noqa: E501

        Skadeomfang. Hva var konsekvensen av hendelsen. Valgene gitt i DamageExtentKD. The DamageExtentKD unique identifier  # noqa: E501

        :return: The damage_extent_tid of this LandSlideObsDto.  # noqa: E501
        :rtype: int
        """
        return self._damage_extent_tid

    @damage_extent_tid.setter
    def damage_extent_tid(self, damage_extent_tid):
        """Sets the damage_extent_tid of this LandSlideObsDto.

        Skadeomfang. Hva var konsekvensen av hendelsen. Valgene gitt i DamageExtentKD. The DamageExtentKD unique identifier  # noqa: E501

        :param damage_extent_tid: The damage_extent_tid of this LandSlideObsDto.  # noqa: E501
        :type: int
        """

        self._damage_extent_tid = damage_extent_tid

    @property
    def comment(self):
        """Gets the comment of this LandSlideObsDto.  # noqa: E501

        Kommentarfelt for å skrive utfyllende tekst om observasjonen.  # noqa: E501

        :return: The comment of this LandSlideObsDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this LandSlideObsDto.

        Kommentarfelt for å skrive utfyllende tekst om observasjonen.  # noqa: E501

        :param comment: The comment of this LandSlideObsDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def urls(self):
        """Gets the urls of this LandSlideObsDto.  # noqa: E501


        :return: The urls of this LandSlideObsDto.  # noqa: E501
        :rtype: list[UrlViewModel]
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """Sets the urls of this LandSlideObsDto.


        :param urls: The urls of this LandSlideObsDto.  # noqa: E501
        :type: list[UrlViewModel]
        """

        self._urls = urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LandSlideObsDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LandSlideObsDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class IceCoverViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ice_cover_before_tid': 'int',
        'ice_cover_before_name': 'str',
        'ice_cover_tid': 'int',
        'ice_cover_name': 'str',
        'comment': 'str',
        'ice_cover_after_tid': 'int',
        'ice_cover_after_name': 'str',
        'ice_skateability_tid': 'int',
        'ice_skateability_name': 'str',
        'ice_capacity_tid': 'int',
        'ice_capacity_name': 'str'
    }

    attribute_map = {
        'ice_cover_before_tid': 'IceCoverBeforeTID',
        'ice_cover_before_name': 'IceCoverBeforeName',
        'ice_cover_tid': 'IceCoverTID',
        'ice_cover_name': 'IceCoverName',
        'comment': 'Comment',
        'ice_cover_after_tid': 'IceCoverAfterTID',
        'ice_cover_after_name': 'IceCoverAfterName',
        'ice_skateability_tid': 'IceSkateabilityTID',
        'ice_skateability_name': 'IceSkateabilityName',
        'ice_capacity_tid': 'IceCapacityTID',
        'ice_capacity_name': 'IceCapacityName'
    }

    def __init__(self, ice_cover_before_tid=None, ice_cover_before_name=None, ice_cover_tid=None, ice_cover_name=None, comment=None, ice_cover_after_tid=None, ice_cover_after_name=None, ice_skateability_tid=None, ice_skateability_name=None, ice_capacity_tid=None, ice_capacity_name=None):  # noqa: E501
        """IceCoverViewModel - a model defined in Swagger"""  # noqa: E501
        self._ice_cover_before_tid = None
        self._ice_cover_before_name = None
        self._ice_cover_tid = None
        self._ice_cover_name = None
        self._comment = None
        self._ice_cover_after_tid = None
        self._ice_cover_after_name = None
        self._ice_skateability_tid = None
        self._ice_skateability_name = None
        self._ice_capacity_tid = None
        self._ice_capacity_name = None
        self.discriminator = None
        if ice_cover_before_tid is not None:
            self.ice_cover_before_tid = ice_cover_before_tid
        if ice_cover_before_name is not None:
            self.ice_cover_before_name = ice_cover_before_name
        if ice_cover_tid is not None:
            self.ice_cover_tid = ice_cover_tid
        if ice_cover_name is not None:
            self.ice_cover_name = ice_cover_name
        if comment is not None:
            self.comment = comment
        if ice_cover_after_tid is not None:
            self.ice_cover_after_tid = ice_cover_after_tid
        if ice_cover_after_name is not None:
            self.ice_cover_after_name = ice_cover_after_name
        if ice_skateability_tid is not None:
            self.ice_skateability_tid = ice_skateability_tid
        if ice_skateability_name is not None:
            self.ice_skateability_name = ice_skateability_name
        if ice_capacity_tid is not None:
            self.ice_capacity_tid = ice_capacity_tid
        if ice_capacity_name is not None:
            self.ice_capacity_name = ice_capacity_name

    @property
    def ice_cover_before_tid(self):
        """Gets the ice_cover_before_tid of this IceCoverViewModel.  # noqa: E501


        :return: The ice_cover_before_tid of this IceCoverViewModel.  # noqa: E501
        :rtype: int
        """
        return self._ice_cover_before_tid

    @ice_cover_before_tid.setter
    def ice_cover_before_tid(self, ice_cover_before_tid):
        """Sets the ice_cover_before_tid of this IceCoverViewModel.


        :param ice_cover_before_tid: The ice_cover_before_tid of this IceCoverViewModel.  # noqa: E501
        :type: int
        """

        self._ice_cover_before_tid = ice_cover_before_tid

    @property
    def ice_cover_before_name(self):
        """Gets the ice_cover_before_name of this IceCoverViewModel.  # noqa: E501


        :return: The ice_cover_before_name of this IceCoverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._ice_cover_before_name

    @ice_cover_before_name.setter
    def ice_cover_before_name(self, ice_cover_before_name):
        """Sets the ice_cover_before_name of this IceCoverViewModel.


        :param ice_cover_before_name: The ice_cover_before_name of this IceCoverViewModel.  # noqa: E501
        :type: str
        """

        self._ice_cover_before_name = ice_cover_before_name

    @property
    def ice_cover_tid(self):
        """Gets the ice_cover_tid of this IceCoverViewModel.  # noqa: E501


        :return: The ice_cover_tid of this IceCoverViewModel.  # noqa: E501
        :rtype: int
        """
        return self._ice_cover_tid

    @ice_cover_tid.setter
    def ice_cover_tid(self, ice_cover_tid):
        """Sets the ice_cover_tid of this IceCoverViewModel.


        :param ice_cover_tid: The ice_cover_tid of this IceCoverViewModel.  # noqa: E501
        :type: int
        """

        self._ice_cover_tid = ice_cover_tid

    @property
    def ice_cover_name(self):
        """Gets the ice_cover_name of this IceCoverViewModel.  # noqa: E501


        :return: The ice_cover_name of this IceCoverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._ice_cover_name

    @ice_cover_name.setter
    def ice_cover_name(self, ice_cover_name):
        """Sets the ice_cover_name of this IceCoverViewModel.


        :param ice_cover_name: The ice_cover_name of this IceCoverViewModel.  # noqa: E501
        :type: str
        """

        self._ice_cover_name = ice_cover_name

    @property
    def comment(self):
        """Gets the comment of this IceCoverViewModel.  # noqa: E501


        :return: The comment of this IceCoverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this IceCoverViewModel.


        :param comment: The comment of this IceCoverViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def ice_cover_after_tid(self):
        """Gets the ice_cover_after_tid of this IceCoverViewModel.  # noqa: E501


        :return: The ice_cover_after_tid of this IceCoverViewModel.  # noqa: E501
        :rtype: int
        """
        return self._ice_cover_after_tid

    @ice_cover_after_tid.setter
    def ice_cover_after_tid(self, ice_cover_after_tid):
        """Sets the ice_cover_after_tid of this IceCoverViewModel.


        :param ice_cover_after_tid: The ice_cover_after_tid of this IceCoverViewModel.  # noqa: E501
        :type: int
        """

        self._ice_cover_after_tid = ice_cover_after_tid

    @property
    def ice_cover_after_name(self):
        """Gets the ice_cover_after_name of this IceCoverViewModel.  # noqa: E501


        :return: The ice_cover_after_name of this IceCoverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._ice_cover_after_name

    @ice_cover_after_name.setter
    def ice_cover_after_name(self, ice_cover_after_name):
        """Sets the ice_cover_after_name of this IceCoverViewModel.


        :param ice_cover_after_name: The ice_cover_after_name of this IceCoverViewModel.  # noqa: E501
        :type: str
        """

        self._ice_cover_after_name = ice_cover_after_name

    @property
    def ice_skateability_tid(self):
        """Gets the ice_skateability_tid of this IceCoverViewModel.  # noqa: E501


        :return: The ice_skateability_tid of this IceCoverViewModel.  # noqa: E501
        :rtype: int
        """
        return self._ice_skateability_tid

    @ice_skateability_tid.setter
    def ice_skateability_tid(self, ice_skateability_tid):
        """Sets the ice_skateability_tid of this IceCoverViewModel.


        :param ice_skateability_tid: The ice_skateability_tid of this IceCoverViewModel.  # noqa: E501
        :type: int
        """

        self._ice_skateability_tid = ice_skateability_tid

    @property
    def ice_skateability_name(self):
        """Gets the ice_skateability_name of this IceCoverViewModel.  # noqa: E501


        :return: The ice_skateability_name of this IceCoverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._ice_skateability_name

    @ice_skateability_name.setter
    def ice_skateability_name(self, ice_skateability_name):
        """Sets the ice_skateability_name of this IceCoverViewModel.


        :param ice_skateability_name: The ice_skateability_name of this IceCoverViewModel.  # noqa: E501
        :type: str
        """

        self._ice_skateability_name = ice_skateability_name

    @property
    def ice_capacity_tid(self):
        """Gets the ice_capacity_tid of this IceCoverViewModel.  # noqa: E501


        :return: The ice_capacity_tid of this IceCoverViewModel.  # noqa: E501
        :rtype: int
        """
        return self._ice_capacity_tid

    @ice_capacity_tid.setter
    def ice_capacity_tid(self, ice_capacity_tid):
        """Sets the ice_capacity_tid of this IceCoverViewModel.


        :param ice_capacity_tid: The ice_capacity_tid of this IceCoverViewModel.  # noqa: E501
        :type: int
        """

        self._ice_capacity_tid = ice_capacity_tid

    @property
    def ice_capacity_name(self):
        """Gets the ice_capacity_name of this IceCoverViewModel.  # noqa: E501


        :return: The ice_capacity_name of this IceCoverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._ice_capacity_name

    @ice_capacity_name.setter
    def ice_capacity_name(self, ice_capacity_name):
        """Sets the ice_capacity_name of this IceCoverViewModel.


        :param ice_capacity_name: The ice_capacity_name of this IceCoverViewModel.  # noqa: E501
        :type: str
        """

        self._ice_capacity_name = ice_capacity_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IceCoverViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IceCoverViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SearchCriteriaRequestDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reg_id': 'int',
        'lang_key': 'int',
        'location_id': 'int',
        'observer_id': 'int',
        'observer_guid': 'str',
        'group_id': 'int',
        'from_date': 'datetime',
        'to_date': 'datetime',
        'from_dt_obs_time': 'datetime',
        'to_dt_obs_time': 'datetime',
        'from_dt_change_time': 'datetime',
        'to_dt_change_time': 'datetime',
        'number_of_records': 'int',
        'offset': 'int',
        'time_zone': 'str',
        'selected_registration_types': 'list[RegistrationTypeCriteriaDto]',
        'selected_regions': 'list[int]',
        'selected_geo_hazards': 'list[int]',
        'observer_competence': 'list[int]',
        'observer_nick_name': 'str',
        'countries': 'list[int]',
        'counties': 'list[str]',
        'text_search': 'str',
        'radius': 'WithinRadiusCriteriaDto',
        'extent': 'WithinExtentCriteriaDto'
    }

    attribute_map = {
        'reg_id': 'RegId',
        'lang_key': 'LangKey',
        'location_id': 'LocationId',
        'observer_id': 'ObserverId',
        'observer_guid': 'ObserverGuid',
        'group_id': 'GroupId',
        'from_date': 'FromDate',
        'to_date': 'ToDate',
        'from_dt_obs_time': 'FromDtObsTime',
        'to_dt_obs_time': 'ToDtObsTime',
        'from_dt_change_time': 'FromDtChangeTime',
        'to_dt_change_time': 'ToDtChangeTime',
        'number_of_records': 'NumberOfRecords',
        'offset': 'Offset',
        'time_zone': 'TimeZone',
        'selected_registration_types': 'SelectedRegistrationTypes',
        'selected_regions': 'SelectedRegions',
        'selected_geo_hazards': 'SelectedGeoHazards',
        'observer_competence': 'ObserverCompetence',
        'observer_nick_name': 'ObserverNickName',
        'countries': 'Countries',
        'counties': 'Counties',
        'text_search': 'TextSearch',
        'radius': 'Radius',
        'extent': 'Extent'
    }

    def __init__(self, reg_id=None, lang_key=None, location_id=None, observer_id=None, observer_guid=None, group_id=None, from_date=None, to_date=None, from_dt_obs_time=None, to_dt_obs_time=None, from_dt_change_time=None, to_dt_change_time=None, number_of_records=None, offset=None, time_zone=None, selected_registration_types=None, selected_regions=None, selected_geo_hazards=None, observer_competence=None, observer_nick_name=None, countries=None, counties=None, text_search=None, radius=None, extent=None):  # noqa: E501
        """SearchCriteriaRequestDto - a model defined in Swagger"""  # noqa: E501
        self._reg_id = None
        self._lang_key = None
        self._location_id = None
        self._observer_id = None
        self._observer_guid = None
        self._group_id = None
        self._from_date = None
        self._to_date = None
        self._from_dt_obs_time = None
        self._to_dt_obs_time = None
        self._from_dt_change_time = None
        self._to_dt_change_time = None
        self._number_of_records = None
        self._offset = None
        self._time_zone = None
        self._selected_registration_types = None
        self._selected_regions = None
        self._selected_geo_hazards = None
        self._observer_competence = None
        self._observer_nick_name = None
        self._countries = None
        self._counties = None
        self._text_search = None
        self._radius = None
        self._extent = None
        self.discriminator = None
        if reg_id is not None:
            self.reg_id = reg_id
        if lang_key is not None:
            self.lang_key = lang_key
        if location_id is not None:
            self.location_id = location_id
        if observer_id is not None:
            self.observer_id = observer_id
        if observer_guid is not None:
            self.observer_guid = observer_guid
        if group_id is not None:
            self.group_id = group_id
        if from_date is not None:
            self.from_date = from_date
        if to_date is not None:
            self.to_date = to_date
        if from_dt_obs_time is not None:
            self.from_dt_obs_time = from_dt_obs_time
        if to_dt_obs_time is not None:
            self.to_dt_obs_time = to_dt_obs_time
        if from_dt_change_time is not None:
            self.from_dt_change_time = from_dt_change_time
        if to_dt_change_time is not None:
            self.to_dt_change_time = to_dt_change_time
        if number_of_records is not None:
            self.number_of_records = number_of_records
        if offset is not None:
            self.offset = offset
        if time_zone is not None:
            self.time_zone = time_zone
        if selected_registration_types is not None:
            self.selected_registration_types = selected_registration_types
        if selected_regions is not None:
            self.selected_regions = selected_regions
        if selected_geo_hazards is not None:
            self.selected_geo_hazards = selected_geo_hazards
        if observer_competence is not None:
            self.observer_competence = observer_competence
        if observer_nick_name is not None:
            self.observer_nick_name = observer_nick_name
        if countries is not None:
            self.countries = countries
        if counties is not None:
            self.counties = counties
        if text_search is not None:
            self.text_search = text_search
        if radius is not None:
            self.radius = radius
        if extent is not None:
            self.extent = extent

    @property
    def reg_id(self):
        """Gets the reg_id of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The reg_id of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._reg_id

    @reg_id.setter
    def reg_id(self, reg_id):
        """Sets the reg_id of this SearchCriteriaRequestDto.


        :param reg_id: The reg_id of this SearchCriteriaRequestDto.  # noqa: E501
        :type: int
        """

        self._reg_id = reg_id

    @property
    def lang_key(self):
        """Gets the lang_key of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The lang_key of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._lang_key

    @lang_key.setter
    def lang_key(self, lang_key):
        """Sets the lang_key of this SearchCriteriaRequestDto.


        :param lang_key: The lang_key of this SearchCriteriaRequestDto.  # noqa: E501
        :type: int
        """

        self._lang_key = lang_key

    @property
    def location_id(self):
        """Gets the location_id of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The location_id of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this SearchCriteriaRequestDto.


        :param location_id: The location_id of this SearchCriteriaRequestDto.  # noqa: E501
        :type: int
        """

        self._location_id = location_id

    @property
    def observer_id(self):
        """Gets the observer_id of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The observer_id of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._observer_id

    @observer_id.setter
    def observer_id(self, observer_id):
        """Sets the observer_id of this SearchCriteriaRequestDto.


        :param observer_id: The observer_id of this SearchCriteriaRequestDto.  # noqa: E501
        :type: int
        """

        self._observer_id = observer_id

    @property
    def observer_guid(self):
        """Gets the observer_guid of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The observer_guid of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._observer_guid

    @observer_guid.setter
    def observer_guid(self, observer_guid):
        """Sets the observer_guid of this SearchCriteriaRequestDto.


        :param observer_guid: The observer_guid of this SearchCriteriaRequestDto.  # noqa: E501
        :type: str
        """

        self._observer_guid = observer_guid

    @property
    def group_id(self):
        """Gets the group_id of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The group_id of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this SearchCriteriaRequestDto.


        :param group_id: The group_id of this SearchCriteriaRequestDto.  # noqa: E501
        :type: int
        """

        self._group_id = group_id

    @property
    def from_date(self):
        """Gets the from_date of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The from_date of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._from_date

    @from_date.setter
    def from_date(self, from_date):
        """Sets the from_date of this SearchCriteriaRequestDto.


        :param from_date: The from_date of this SearchCriteriaRequestDto.  # noqa: E501
        :type: datetime
        """

        self._from_date = from_date

    @property
    def to_date(self):
        """Gets the to_date of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The to_date of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._to_date

    @to_date.setter
    def to_date(self, to_date):
        """Sets the to_date of this SearchCriteriaRequestDto.


        :param to_date: The to_date of this SearchCriteriaRequestDto.  # noqa: E501
        :type: datetime
        """

        self._to_date = to_date

    @property
    def from_dt_obs_time(self):
        """Gets the from_dt_obs_time of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The from_dt_obs_time of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._from_dt_obs_time

    @from_dt_obs_time.setter
    def from_dt_obs_time(self, from_dt_obs_time):
        """Sets the from_dt_obs_time of this SearchCriteriaRequestDto.


        :param from_dt_obs_time: The from_dt_obs_time of this SearchCriteriaRequestDto.  # noqa: E501
        :type: datetime
        """

        self._from_dt_obs_time = from_dt_obs_time

    @property
    def to_dt_obs_time(self):
        """Gets the to_dt_obs_time of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The to_dt_obs_time of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._to_dt_obs_time

    @to_dt_obs_time.setter
    def to_dt_obs_time(self, to_dt_obs_time):
        """Sets the to_dt_obs_time of this SearchCriteriaRequestDto.


        :param to_dt_obs_time: The to_dt_obs_time of this SearchCriteriaRequestDto.  # noqa: E501
        :type: datetime
        """

        self._to_dt_obs_time = to_dt_obs_time

    @property
    def from_dt_change_time(self):
        """Gets the from_dt_change_time of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The from_dt_change_time of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._from_dt_change_time

    @from_dt_change_time.setter
    def from_dt_change_time(self, from_dt_change_time):
        """Sets the from_dt_change_time of this SearchCriteriaRequestDto.


        :param from_dt_change_time: The from_dt_change_time of this SearchCriteriaRequestDto.  # noqa: E501
        :type: datetime
        """

        self._from_dt_change_time = from_dt_change_time

    @property
    def to_dt_change_time(self):
        """Gets the to_dt_change_time of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The to_dt_change_time of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._to_dt_change_time

    @to_dt_change_time.setter
    def to_dt_change_time(self, to_dt_change_time):
        """Sets the to_dt_change_time of this SearchCriteriaRequestDto.


        :param to_dt_change_time: The to_dt_change_time of this SearchCriteriaRequestDto.  # noqa: E501
        :type: datetime
        """

        self._to_dt_change_time = to_dt_change_time

    @property
    def number_of_records(self):
        """Gets the number_of_records of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The number_of_records of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._number_of_records

    @number_of_records.setter
    def number_of_records(self, number_of_records):
        """Sets the number_of_records of this SearchCriteriaRequestDto.


        :param number_of_records: The number_of_records of this SearchCriteriaRequestDto.  # noqa: E501
        :type: int
        """

        self._number_of_records = number_of_records

    @property
    def offset(self):
        """Gets the offset of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The offset of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this SearchCriteriaRequestDto.


        :param offset: The offset of this SearchCriteriaRequestDto.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def time_zone(self):
        """Gets the time_zone of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The time_zone of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this SearchCriteriaRequestDto.


        :param time_zone: The time_zone of this SearchCriteriaRequestDto.  # noqa: E501
        :type: str
        """

        self._time_zone = time_zone

    @property
    def selected_registration_types(self):
        """Gets the selected_registration_types of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The selected_registration_types of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: list[RegistrationTypeCriteriaDto]
        """
        return self._selected_registration_types

    @selected_registration_types.setter
    def selected_registration_types(self, selected_registration_types):
        """Sets the selected_registration_types of this SearchCriteriaRequestDto.


        :param selected_registration_types: The selected_registration_types of this SearchCriteriaRequestDto.  # noqa: E501
        :type: list[RegistrationTypeCriteriaDto]
        """

        self._selected_registration_types = selected_registration_types

    @property
    def selected_regions(self):
        """Gets the selected_regions of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The selected_regions of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: list[int]
        """
        return self._selected_regions

    @selected_regions.setter
    def selected_regions(self, selected_regions):
        """Sets the selected_regions of this SearchCriteriaRequestDto.


        :param selected_regions: The selected_regions of this SearchCriteriaRequestDto.  # noqa: E501
        :type: list[int]
        """

        self._selected_regions = selected_regions

    @property
    def selected_geo_hazards(self):
        """Gets the selected_geo_hazards of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The selected_geo_hazards of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: list[int]
        """
        return self._selected_geo_hazards

    @selected_geo_hazards.setter
    def selected_geo_hazards(self, selected_geo_hazards):
        """Sets the selected_geo_hazards of this SearchCriteriaRequestDto.


        :param selected_geo_hazards: The selected_geo_hazards of this SearchCriteriaRequestDto.  # noqa: E501
        :type: list[int]
        """

        self._selected_geo_hazards = selected_geo_hazards

    @property
    def observer_competence(self):
        """Gets the observer_competence of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The observer_competence of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: list[int]
        """
        return self._observer_competence

    @observer_competence.setter
    def observer_competence(self, observer_competence):
        """Sets the observer_competence of this SearchCriteriaRequestDto.


        :param observer_competence: The observer_competence of this SearchCriteriaRequestDto.  # noqa: E501
        :type: list[int]
        """

        self._observer_competence = observer_competence

    @property
    def observer_nick_name(self):
        """Gets the observer_nick_name of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The observer_nick_name of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._observer_nick_name

    @observer_nick_name.setter
    def observer_nick_name(self, observer_nick_name):
        """Sets the observer_nick_name of this SearchCriteriaRequestDto.


        :param observer_nick_name: The observer_nick_name of this SearchCriteriaRequestDto.  # noqa: E501
        :type: str
        """

        self._observer_nick_name = observer_nick_name

    @property
    def countries(self):
        """Gets the countries of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The countries of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: list[int]
        """
        return self._countries

    @countries.setter
    def countries(self, countries):
        """Sets the countries of this SearchCriteriaRequestDto.


        :param countries: The countries of this SearchCriteriaRequestDto.  # noqa: E501
        :type: list[int]
        """

        self._countries = countries

    @property
    def counties(self):
        """Gets the counties of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The counties of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._counties

    @counties.setter
    def counties(self, counties):
        """Sets the counties of this SearchCriteriaRequestDto.


        :param counties: The counties of this SearchCriteriaRequestDto.  # noqa: E501
        :type: list[str]
        """

        self._counties = counties

    @property
    def text_search(self):
        """Gets the text_search of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The text_search of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._text_search

    @text_search.setter
    def text_search(self, text_search):
        """Sets the text_search of this SearchCriteriaRequestDto.


        :param text_search: The text_search of this SearchCriteriaRequestDto.  # noqa: E501
        :type: str
        """

        self._text_search = text_search

    @property
    def radius(self):
        """Gets the radius of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The radius of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: WithinRadiusCriteriaDto
        """
        return self._radius

    @radius.setter
    def radius(self, radius):
        """Sets the radius of this SearchCriteriaRequestDto.


        :param radius: The radius of this SearchCriteriaRequestDto.  # noqa: E501
        :type: WithinRadiusCriteriaDto
        """

        self._radius = radius

    @property
    def extent(self):
        """Gets the extent of this SearchCriteriaRequestDto.  # noqa: E501


        :return: The extent of this SearchCriteriaRequestDto.  # noqa: E501
        :rtype: WithinExtentCriteriaDto
        """
        return self._extent

    @extent.setter
    def extent(self, extent):
        """Sets the extent of this SearchCriteriaRequestDto.


        :param extent: The extent of this SearchCriteriaRequestDto.  # noqa: E501
        :type: WithinExtentCriteriaDto
        """

        self._extent = extent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchCriteriaRequestDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchCriteriaRequestDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheEvalProblem2ViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avalanche_eval_problem_id': 'int',
        'aval_probability_tid': 'int',
        'aval_probability_name': 'str',
        'aval_trigger_simple_tid': 'int',
        'aval_trigger_simple_name': 'str',
        'aval_cause_depth_tid': 'int',
        'aval_cause_depth_name': 'str',
        'valid_exposition': 'str',
        'exposed_height1': 'int',
        'exposed_height2': 'int',
        'exposed_height_combo_tid': 'int',
        'exposed_height_combo_name': 'str',
        'avalanche_ext_tid': 'int',
        'avalanche_ext_name': 'str',
        'comment': 'str',
        'aval_cause_tid': 'int',
        'aval_cause_name': 'str',
        'destructive_size_tid': 'int',
        'destructive_size_name': 'str',
        'aval_propagation_tid': 'int',
        'aval_propagation_name': 'str',
        'aval_cause_attribute_light_tid': 'int',
        'aval_cause_attribute_light_name': 'str',
        'aval_cause_attribute_thin_tid': 'int',
        'aval_cause_attribute_thin_name': 'str',
        'aval_cause_attribute_soft_tid': 'int',
        'aval_cause_attribute_soft_name': 'str',
        'aval_cause_attribute_crystal_tid': 'int',
        'aval_cause_attribute_crystal_name': 'str'
    }

    attribute_map = {
        'avalanche_eval_problem_id': 'AvalancheEvalProblemID',
        'aval_probability_tid': 'AvalProbabilityTID',
        'aval_probability_name': 'AvalProbabilityName',
        'aval_trigger_simple_tid': 'AvalTriggerSimpleTID',
        'aval_trigger_simple_name': 'AvalTriggerSimpleName',
        'aval_cause_depth_tid': 'AvalCauseDepthTID',
        'aval_cause_depth_name': 'AvalCauseDepthName',
        'valid_exposition': 'ValidExposition',
        'exposed_height1': 'ExposedHeight1',
        'exposed_height2': 'ExposedHeight2',
        'exposed_height_combo_tid': 'ExposedHeightComboTID',
        'exposed_height_combo_name': 'ExposedHeightComboName',
        'avalanche_ext_tid': 'AvalancheExtTID',
        'avalanche_ext_name': 'AvalancheExtName',
        'comment': 'Comment',
        'aval_cause_tid': 'AvalCauseTID',
        'aval_cause_name': 'AvalCauseName',
        'destructive_size_tid': 'DestructiveSizeTID',
        'destructive_size_name': 'DestructiveSizeName',
        'aval_propagation_tid': 'AvalPropagationTID',
        'aval_propagation_name': 'AvalPropagationName',
        'aval_cause_attribute_light_tid': 'AvalCauseAttributeLightTID',
        'aval_cause_attribute_light_name': 'AvalCauseAttributeLightName',
        'aval_cause_attribute_thin_tid': 'AvalCauseAttributeThinTID',
        'aval_cause_attribute_thin_name': 'AvalCauseAttributeThinName',
        'aval_cause_attribute_soft_tid': 'AvalCauseAttributeSoftTID',
        'aval_cause_attribute_soft_name': 'AvalCauseAttributeSoftName',
        'aval_cause_attribute_crystal_tid': 'AvalCauseAttributeCrystalTID',
        'aval_cause_attribute_crystal_name': 'AvalCauseAttributeCrystalName'
    }

    def __init__(self, avalanche_eval_problem_id=None, aval_probability_tid=None, aval_probability_name=None, aval_trigger_simple_tid=None, aval_trigger_simple_name=None, aval_cause_depth_tid=None, aval_cause_depth_name=None, valid_exposition=None, exposed_height1=None, exposed_height2=None, exposed_height_combo_tid=None, exposed_height_combo_name=None, avalanche_ext_tid=None, avalanche_ext_name=None, comment=None, aval_cause_tid=None, aval_cause_name=None, destructive_size_tid=None, destructive_size_name=None, aval_propagation_tid=None, aval_propagation_name=None, aval_cause_attribute_light_tid=None, aval_cause_attribute_light_name=None, aval_cause_attribute_thin_tid=None, aval_cause_attribute_thin_name=None, aval_cause_attribute_soft_tid=None, aval_cause_attribute_soft_name=None, aval_cause_attribute_crystal_tid=None, aval_cause_attribute_crystal_name=None):  # noqa: E501
        """AvalancheEvalProblem2ViewModel - a model defined in Swagger"""  # noqa: E501
        self._avalanche_eval_problem_id = None
        self._aval_probability_tid = None
        self._aval_probability_name = None
        self._aval_trigger_simple_tid = None
        self._aval_trigger_simple_name = None
        self._aval_cause_depth_tid = None
        self._aval_cause_depth_name = None
        self._valid_exposition = None
        self._exposed_height1 = None
        self._exposed_height2 = None
        self._exposed_height_combo_tid = None
        self._exposed_height_combo_name = None
        self._avalanche_ext_tid = None
        self._avalanche_ext_name = None
        self._comment = None
        self._aval_cause_tid = None
        self._aval_cause_name = None
        self._destructive_size_tid = None
        self._destructive_size_name = None
        self._aval_propagation_tid = None
        self._aval_propagation_name = None
        self._aval_cause_attribute_light_tid = None
        self._aval_cause_attribute_light_name = None
        self._aval_cause_attribute_thin_tid = None
        self._aval_cause_attribute_thin_name = None
        self._aval_cause_attribute_soft_tid = None
        self._aval_cause_attribute_soft_name = None
        self._aval_cause_attribute_crystal_tid = None
        self._aval_cause_attribute_crystal_name = None
        self.discriminator = None
        if avalanche_eval_problem_id is not None:
            self.avalanche_eval_problem_id = avalanche_eval_problem_id
        if aval_probability_tid is not None:
            self.aval_probability_tid = aval_probability_tid
        if aval_probability_name is not None:
            self.aval_probability_name = aval_probability_name
        if aval_trigger_simple_tid is not None:
            self.aval_trigger_simple_tid = aval_trigger_simple_tid
        if aval_trigger_simple_name is not None:
            self.aval_trigger_simple_name = aval_trigger_simple_name
        if aval_cause_depth_tid is not None:
            self.aval_cause_depth_tid = aval_cause_depth_tid
        if aval_cause_depth_name is not None:
            self.aval_cause_depth_name = aval_cause_depth_name
        if valid_exposition is not None:
            self.valid_exposition = valid_exposition
        if exposed_height1 is not None:
            self.exposed_height1 = exposed_height1
        if exposed_height2 is not None:
            self.exposed_height2 = exposed_height2
        if exposed_height_combo_tid is not None:
            self.exposed_height_combo_tid = exposed_height_combo_tid
        if exposed_height_combo_name is not None:
            self.exposed_height_combo_name = exposed_height_combo_name
        if avalanche_ext_tid is not None:
            self.avalanche_ext_tid = avalanche_ext_tid
        if avalanche_ext_name is not None:
            self.avalanche_ext_name = avalanche_ext_name
        if comment is not None:
            self.comment = comment
        if aval_cause_tid is not None:
            self.aval_cause_tid = aval_cause_tid
        if aval_cause_name is not None:
            self.aval_cause_name = aval_cause_name
        if destructive_size_tid is not None:
            self.destructive_size_tid = destructive_size_tid
        if destructive_size_name is not None:
            self.destructive_size_name = destructive_size_name
        if aval_propagation_tid is not None:
            self.aval_propagation_tid = aval_propagation_tid
        if aval_propagation_name is not None:
            self.aval_propagation_name = aval_propagation_name
        if aval_cause_attribute_light_tid is not None:
            self.aval_cause_attribute_light_tid = aval_cause_attribute_light_tid
        if aval_cause_attribute_light_name is not None:
            self.aval_cause_attribute_light_name = aval_cause_attribute_light_name
        if aval_cause_attribute_thin_tid is not None:
            self.aval_cause_attribute_thin_tid = aval_cause_attribute_thin_tid
        if aval_cause_attribute_thin_name is not None:
            self.aval_cause_attribute_thin_name = aval_cause_attribute_thin_name
        if aval_cause_attribute_soft_tid is not None:
            self.aval_cause_attribute_soft_tid = aval_cause_attribute_soft_tid
        if aval_cause_attribute_soft_name is not None:
            self.aval_cause_attribute_soft_name = aval_cause_attribute_soft_name
        if aval_cause_attribute_crystal_tid is not None:
            self.aval_cause_attribute_crystal_tid = aval_cause_attribute_crystal_tid
        if aval_cause_attribute_crystal_name is not None:
            self.aval_cause_attribute_crystal_name = aval_cause_attribute_crystal_name

    @property
    def avalanche_eval_problem_id(self):
        """Gets the avalanche_eval_problem_id of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The avalanche_eval_problem_id of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_eval_problem_id

    @avalanche_eval_problem_id.setter
    def avalanche_eval_problem_id(self, avalanche_eval_problem_id):
        """Sets the avalanche_eval_problem_id of this AvalancheEvalProblem2ViewModel.


        :param avalanche_eval_problem_id: The avalanche_eval_problem_id of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_eval_problem_id = avalanche_eval_problem_id

    @property
    def aval_probability_tid(self):
        """Gets the aval_probability_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_probability_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_probability_tid

    @aval_probability_tid.setter
    def aval_probability_tid(self, aval_probability_tid):
        """Sets the aval_probability_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_probability_tid: The aval_probability_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_probability_tid = aval_probability_tid

    @property
    def aval_probability_name(self):
        """Gets the aval_probability_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_probability_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_probability_name

    @aval_probability_name.setter
    def aval_probability_name(self, aval_probability_name):
        """Sets the aval_probability_name of this AvalancheEvalProblem2ViewModel.


        :param aval_probability_name: The aval_probability_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_probability_name = aval_probability_name

    @property
    def aval_trigger_simple_tid(self):
        """Gets the aval_trigger_simple_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_trigger_simple_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_trigger_simple_tid

    @aval_trigger_simple_tid.setter
    def aval_trigger_simple_tid(self, aval_trigger_simple_tid):
        """Sets the aval_trigger_simple_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_trigger_simple_tid: The aval_trigger_simple_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_trigger_simple_tid = aval_trigger_simple_tid

    @property
    def aval_trigger_simple_name(self):
        """Gets the aval_trigger_simple_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_trigger_simple_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_trigger_simple_name

    @aval_trigger_simple_name.setter
    def aval_trigger_simple_name(self, aval_trigger_simple_name):
        """Sets the aval_trigger_simple_name of this AvalancheEvalProblem2ViewModel.


        :param aval_trigger_simple_name: The aval_trigger_simple_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_trigger_simple_name = aval_trigger_simple_name

    @property
    def aval_cause_depth_tid(self):
        """Gets the aval_cause_depth_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_depth_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_depth_tid

    @aval_cause_depth_tid.setter
    def aval_cause_depth_tid(self, aval_cause_depth_tid):
        """Sets the aval_cause_depth_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_depth_tid: The aval_cause_depth_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_depth_tid = aval_cause_depth_tid

    @property
    def aval_cause_depth_name(self):
        """Gets the aval_cause_depth_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_depth_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_depth_name

    @aval_cause_depth_name.setter
    def aval_cause_depth_name(self, aval_cause_depth_name):
        """Sets the aval_cause_depth_name of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_depth_name: The aval_cause_depth_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_depth_name = aval_cause_depth_name

    @property
    def valid_exposition(self):
        """Gets the valid_exposition of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The valid_exposition of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._valid_exposition

    @valid_exposition.setter
    def valid_exposition(self, valid_exposition):
        """Sets the valid_exposition of this AvalancheEvalProblem2ViewModel.


        :param valid_exposition: The valid_exposition of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._valid_exposition = valid_exposition

    @property
    def exposed_height1(self):
        """Gets the exposed_height1 of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The exposed_height1 of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height1

    @exposed_height1.setter
    def exposed_height1(self, exposed_height1):
        """Sets the exposed_height1 of this AvalancheEvalProblem2ViewModel.


        :param exposed_height1: The exposed_height1 of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height1 = exposed_height1

    @property
    def exposed_height2(self):
        """Gets the exposed_height2 of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The exposed_height2 of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height2

    @exposed_height2.setter
    def exposed_height2(self, exposed_height2):
        """Sets the exposed_height2 of this AvalancheEvalProblem2ViewModel.


        :param exposed_height2: The exposed_height2 of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height2 = exposed_height2

    @property
    def exposed_height_combo_tid(self):
        """Gets the exposed_height_combo_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The exposed_height_combo_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height_combo_tid

    @exposed_height_combo_tid.setter
    def exposed_height_combo_tid(self, exposed_height_combo_tid):
        """Sets the exposed_height_combo_tid of this AvalancheEvalProblem2ViewModel.


        :param exposed_height_combo_tid: The exposed_height_combo_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height_combo_tid = exposed_height_combo_tid

    @property
    def exposed_height_combo_name(self):
        """Gets the exposed_height_combo_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The exposed_height_combo_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._exposed_height_combo_name

    @exposed_height_combo_name.setter
    def exposed_height_combo_name(self, exposed_height_combo_name):
        """Sets the exposed_height_combo_name of this AvalancheEvalProblem2ViewModel.


        :param exposed_height_combo_name: The exposed_height_combo_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._exposed_height_combo_name = exposed_height_combo_name

    @property
    def avalanche_ext_tid(self):
        """Gets the avalanche_ext_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The avalanche_ext_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_ext_tid

    @avalanche_ext_tid.setter
    def avalanche_ext_tid(self, avalanche_ext_tid):
        """Sets the avalanche_ext_tid of this AvalancheEvalProblem2ViewModel.


        :param avalanche_ext_tid: The avalanche_ext_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_ext_tid = avalanche_ext_tid

    @property
    def avalanche_ext_name(self):
        """Gets the avalanche_ext_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The avalanche_ext_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_ext_name

    @avalanche_ext_name.setter
    def avalanche_ext_name(self, avalanche_ext_name):
        """Sets the avalanche_ext_name of this AvalancheEvalProblem2ViewModel.


        :param avalanche_ext_name: The avalanche_ext_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_ext_name = avalanche_ext_name

    @property
    def comment(self):
        """Gets the comment of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The comment of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheEvalProblem2ViewModel.


        :param comment: The comment of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def aval_cause_tid(self):
        """Gets the aval_cause_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_tid

    @aval_cause_tid.setter
    def aval_cause_tid(self, aval_cause_tid):
        """Sets the aval_cause_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_tid: The aval_cause_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_tid = aval_cause_tid

    @property
    def aval_cause_name(self):
        """Gets the aval_cause_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_name

    @aval_cause_name.setter
    def aval_cause_name(self, aval_cause_name):
        """Sets the aval_cause_name of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_name: The aval_cause_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_name = aval_cause_name

    @property
    def destructive_size_tid(self):
        """Gets the destructive_size_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The destructive_size_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._destructive_size_tid

    @destructive_size_tid.setter
    def destructive_size_tid(self, destructive_size_tid):
        """Sets the destructive_size_tid of this AvalancheEvalProblem2ViewModel.


        :param destructive_size_tid: The destructive_size_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._destructive_size_tid = destructive_size_tid

    @property
    def destructive_size_name(self):
        """Gets the destructive_size_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The destructive_size_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._destructive_size_name

    @destructive_size_name.setter
    def destructive_size_name(self, destructive_size_name):
        """Sets the destructive_size_name of this AvalancheEvalProblem2ViewModel.


        :param destructive_size_name: The destructive_size_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._destructive_size_name = destructive_size_name

    @property
    def aval_propagation_tid(self):
        """Gets the aval_propagation_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_propagation_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_propagation_tid

    @aval_propagation_tid.setter
    def aval_propagation_tid(self, aval_propagation_tid):
        """Sets the aval_propagation_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_propagation_tid: The aval_propagation_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_propagation_tid = aval_propagation_tid

    @property
    def aval_propagation_name(self):
        """Gets the aval_propagation_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_propagation_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_propagation_name

    @aval_propagation_name.setter
    def aval_propagation_name(self, aval_propagation_name):
        """Sets the aval_propagation_name of this AvalancheEvalProblem2ViewModel.


        :param aval_propagation_name: The aval_propagation_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_propagation_name = aval_propagation_name

    @property
    def aval_cause_attribute_light_tid(self):
        """Gets the aval_cause_attribute_light_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_attribute_light_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_attribute_light_tid

    @aval_cause_attribute_light_tid.setter
    def aval_cause_attribute_light_tid(self, aval_cause_attribute_light_tid):
        """Sets the aval_cause_attribute_light_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_attribute_light_tid: The aval_cause_attribute_light_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_attribute_light_tid = aval_cause_attribute_light_tid

    @property
    def aval_cause_attribute_light_name(self):
        """Gets the aval_cause_attribute_light_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_attribute_light_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_attribute_light_name

    @aval_cause_attribute_light_name.setter
    def aval_cause_attribute_light_name(self, aval_cause_attribute_light_name):
        """Sets the aval_cause_attribute_light_name of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_attribute_light_name: The aval_cause_attribute_light_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_attribute_light_name = aval_cause_attribute_light_name

    @property
    def aval_cause_attribute_thin_tid(self):
        """Gets the aval_cause_attribute_thin_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_attribute_thin_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_attribute_thin_tid

    @aval_cause_attribute_thin_tid.setter
    def aval_cause_attribute_thin_tid(self, aval_cause_attribute_thin_tid):
        """Sets the aval_cause_attribute_thin_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_attribute_thin_tid: The aval_cause_attribute_thin_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_attribute_thin_tid = aval_cause_attribute_thin_tid

    @property
    def aval_cause_attribute_thin_name(self):
        """Gets the aval_cause_attribute_thin_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_attribute_thin_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_attribute_thin_name

    @aval_cause_attribute_thin_name.setter
    def aval_cause_attribute_thin_name(self, aval_cause_attribute_thin_name):
        """Sets the aval_cause_attribute_thin_name of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_attribute_thin_name: The aval_cause_attribute_thin_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_attribute_thin_name = aval_cause_attribute_thin_name

    @property
    def aval_cause_attribute_soft_tid(self):
        """Gets the aval_cause_attribute_soft_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_attribute_soft_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_attribute_soft_tid

    @aval_cause_attribute_soft_tid.setter
    def aval_cause_attribute_soft_tid(self, aval_cause_attribute_soft_tid):
        """Sets the aval_cause_attribute_soft_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_attribute_soft_tid: The aval_cause_attribute_soft_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_attribute_soft_tid = aval_cause_attribute_soft_tid

    @property
    def aval_cause_attribute_soft_name(self):
        """Gets the aval_cause_attribute_soft_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_attribute_soft_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_attribute_soft_name

    @aval_cause_attribute_soft_name.setter
    def aval_cause_attribute_soft_name(self, aval_cause_attribute_soft_name):
        """Sets the aval_cause_attribute_soft_name of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_attribute_soft_name: The aval_cause_attribute_soft_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_attribute_soft_name = aval_cause_attribute_soft_name

    @property
    def aval_cause_attribute_crystal_tid(self):
        """Gets the aval_cause_attribute_crystal_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_attribute_crystal_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_attribute_crystal_tid

    @aval_cause_attribute_crystal_tid.setter
    def aval_cause_attribute_crystal_tid(self, aval_cause_attribute_crystal_tid):
        """Sets the aval_cause_attribute_crystal_tid of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_attribute_crystal_tid: The aval_cause_attribute_crystal_tid of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_attribute_crystal_tid = aval_cause_attribute_crystal_tid

    @property
    def aval_cause_attribute_crystal_name(self):
        """Gets the aval_cause_attribute_crystal_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501


        :return: The aval_cause_attribute_crystal_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_attribute_crystal_name

    @aval_cause_attribute_crystal_name.setter
    def aval_cause_attribute_crystal_name(self, aval_cause_attribute_crystal_name):
        """Sets the aval_cause_attribute_crystal_name of this AvalancheEvalProblem2ViewModel.


        :param aval_cause_attribute_crystal_name: The aval_cause_attribute_crystal_name of this AvalancheEvalProblem2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_attribute_crystal_name = aval_cause_attribute_crystal_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheEvalProblem2ViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheEvalProblem2ViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
